@@ -37,7 +37,7 @@ use strict;
 
 my @groups = (
     "qtbase", "qtdeclarative", "qtxmlpatterns", "qtmultimedia", "qtscript", "qtquick1",
-    "qtlocation", "qtconnectivity", "qtwebsockets",
+    "qtlocation", "qtconnectivity", "qtwebsockets", "qtserialport", "qtwebengine",
 #    "qtdocgallery", "qtpim", "qtsystems",
     "assistant", "designer", "linguist", "qt_help", "qtconfig", "qmlviewer"
 );
